import { jsx as _jsx } from "react/jsx-runtime";
// src/__tests__/useOverflowScroll.test.tsx
import { render, fireEvent, cleanup } from "@testing-library/react";
import { OverflowedComponent } from "./mocks/OverflowedComponent";
describe("useOverflowScroll", function () {
    var addEventListenerSpy;
    var removeEventListenerSpy;
    beforeEach(function () {
        addEventListenerSpy = jest.spyOn(document, "addEventListener");
        removeEventListenerSpy = jest.spyOn(document, "removeEventListener");
    });
    afterEach(function () {
        cleanup();
        jest.clearAllMocks();
    });
    it("should add overflow auto on overflowed element", function () {
        var getByTestId = render(_jsx(OverflowedComponent, {})).getByTestId;
        var overflowedElement = getByTestId("overflowed-div");
        var isOverflowed = overflowedElement.scrollHeight > overflowedElement.clientHeight ||
            overflowedElement.scrollWidth > overflowedElement.clientWidth;
        var status = isOverflowed ? "auto" : "visible";
        expect(overflowedElement.style.overflow).toBe(status);
    });
    it("should allow an overflowed element to be dragged", function () {
        var getByTestId = render(_jsx(OverflowedComponent, {})).getByTestId;
        var overflowedElement = getByTestId("overflowed-div");
        fireEvent.mouseDown(overflowedElement, { clientX: 50, clientY: 50 });
        expect(overflowedElement.style.cursor).toBe("grabbing");
        fireEvent.mouseMove(overflowedElement, { clientX: 60, clientY: 60 });
        fireEvent.mouseUp(overflowedElement);
        expect(overflowedElement.style.cursor).toBe("grab");
    });
    it("should clean up event listeners on unmount", function () {
        var unmount = render(_jsx(OverflowedComponent, {})).unmount;
        unmount();
        expect(removeEventListenerSpy).toHaveBeenCalledTimes(2);
    });
    it("should not add event listeners if ref is null", function () {
        var unmount = render(_jsx(OverflowedComponent, {})).unmount;
        unmount();
        expect(addEventListenerSpy).not.toHaveBeenCalled();
    });
    it("number of event listeners added should be equal to number of remove event listeners", function () {
        var getByTestId = render(_jsx(OverflowedComponent, {})).getByTestId;
        var overflowedElement = getByTestId("overflowed-div");
        fireEvent.mouseDown(overflowedElement, { clientX: 50, clientY: 50 });
        fireEvent.mouseUp(overflowedElement);
        expect(addEventListenerSpy).toHaveBeenCalledTimes(removeEventListenerSpy.mock.calls.length);
    });
});
