import { useRef, useEffect } from "react";
export default function useOverflowScroll() {
    var ref = useRef(null);
    var isDragging = useRef(false);
    var startPos = useRef({ x: 0, y: 0 });
    function handleMouseMove(event) {
        var div = ref.current;
        if (!isDragging.current || !div)
            return;
        div.scrollLeft -= event.movementX;
        div.scrollTop -= event.movementY;
    }
    function handleMouseUp() {
        var div = ref.current;
        if (!div)
            return;
        div.style.cursor = "grab";
        isDragging.current = false;
        removeEventListeners();
    }
    function handleMouseDown(event) {
        var div = ref.current;
        if (!div)
            return;
        div.style.cursor = "grabbing";
        isDragging.current = true;
        startPos.current = {
            x: event.pageX - div.offsetLeft,
            y: event.pageY - div.offsetTop,
        };
        addEventListeners();
        event.preventDefault();
    }
    function addEventListeners() {
        document.addEventListener("mousemove", handleMouseMove);
        document.addEventListener("mouseup", handleMouseUp);
    }
    function removeEventListeners() {
        document.removeEventListener("mousemove", handleMouseMove);
        document.removeEventListener("mouseup", handleMouseUp);
    }
    useEffect(function () {
        var div = ref.current;
        if (!div)
            return;
        var isOverflowed = div.scrollHeight > div.clientHeight || div.scrollWidth > div.clientWidth;
        div.style.overflow = isOverflowed ? "auto" : "visible";
        div.style.cursor = isOverflowed ? "grab" : "auto";
        div.addEventListener("mousedown", handleMouseDown);
        return function () {
            div.removeEventListener("mousedown", handleMouseDown);
            removeEventListeners();
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    return ref;
}
